@@ -11,7 +11,7 @@ use std::{process, thread, time};
 use time::Duration;
 
 /// Avoid getting rate limited by Bitfinex.
-const RATE_LIMIT: f32 = 0.5;
+const RATE_LIMIT: f32 = 1.85;
 /// Slice of data to be downloaded.
 const STEP_SIZE: i64 = 86400000;
 
@@ -29,7 +29,7 @@ Returns:
     Vec<CandleData>: A vector of FloatOrInt.
 ```
     */
-pub fn get_candles(
+fn get_candles(
     ticker: &str,
     mut start_time: i64,
     end_time: i64,
